:: Disclaimer: scripts are provided as-is and most of them use tools that are open source
:: or require a (small) license fee when used in a commercial environment. It is the 
:: responsibility of the end user that use scripts to respect the license agreement for
:: these tools. EFI can not be held responsible in any way if scripts don't behave like
:: they should do resulting in any form of financial loss or downtime. Have a good day.  

:: Gets information from a (MJM) JDF ticket and create a master variable file so that 
:: Pitstop can add the ticket data as a slug line

:: 08 2019 - Hans Sep, first very rough version for POC

:: Fiery JobFlow provided arguments
set INPUT=%~1
set OUTPUT=%~2
set JOBNAME=%~n3
set WORKFLOW=%~4
set PREFLIGHT=%~5
set VAULT=%~6
set NEXTMODULEID=%~7

::Static arguments
set pathScript=%~dp0
set ScriptName=%~n0
set pathLog=%VAULT%\%ScriptName%.log
set pathInclude=%pathScript%\_include
set pathJSON=%VAULT%\params_%NEXTMODULEID%.json

::Helper Apps
:: #efi-duplicate#
set pathEFIDuplicate=%pathInclude%\efi-duplicate\duplicate.exe
if not exist %pathEFIDuplicate% (
    >>%pathLog% echo %DATE% %TIME% [ERROR] Can't find %pathEFIDuplicate%. Exit script.
    exit /b 1
)
:: #xmlstarlet#
set pathXML=%pathInclude%\xmlstarlet\xml.exe
if not exist %pathXML% (
    >>%pathLog% echo %DATE% %TIME% [ERROR] Cannot find %pathXML%. Download from http://xmlstar.sourceforge.net Exit script.
    exit /b 1
)

:: For this POC we capture the following data from the JDF ticket:

:: Order number: /JDF/JDF/ResourcePool/CustomerInfo@CustomerOrderID
:: Order name: /JDF/JDF/@DescriptiveName
:: Quantity: /JDF/JDF/ResourcePool/DeliveryParams/Drop/DropItem/@Amount
:: Finished size: /JDF/JDF/Comment

set txtOrderNumber=
set txtOrderName=
set numQuantity=0
set txtFinishedSize=

:get_quantity
for /f "delims=" %%Q in ('%pathXML% sel -N JDF^="http://www.CIP4.org/JDFSchema_1_1" -t -m "/JDF:JDF/JDF:JDF/JDF:ResourcePool/JDF:DeliveryParams/JDF:Drop/JDF:DropItem/@Amount" -v . -n "%VAULT%\part2"') do set /a numQuantity=%%Q
>>%pathLog% echo %DATE% %TIME% [INFO] Quantity: %numQuantity%

:get_ordername
for /f "delims=" %%N in ('%pathXML% sel -N JDF^="http://www.CIP4.org/JDFSchema_1_1" -t -m "/JDF:JDF/JDF:JDF/@DescriptiveName" -v . -n "%VAULT%\part2"') do set txtOrderName=%%N
>>%pathLog% echo %DATE% %TIME% [INFO] Order name: %txtOrderName%

:get_ordernumber
for /f "delims=" %%R in ('%pathXML% sel -N JDF^="http://www.CIP4.org/JDFSchema_1_1" -t -m "/JDF:JDF/JDF:JDF/JDF:ResourcePool/JDF:CustomerInfo/@CustomerOrderID" -v . -n "%VAULT%\part2"') do set txtOrderNumber=%%R
>>%pathLog% echo %DATE% %TIME% [INFO] Order number: %txtOrderNumber%

:get_finishedsize
for /f "delims=" %%S in ('%pathXML% sel -N JDF^="http://www.CIP4.org/JDFSchema_1_1" -t -m "/JDF:JDF/JDF:JDF/JDF:Comment[1]" -v . -n "%VAULT%\part2"') do set txtFinishedSize=%%S
>>%pathLog% echo %DATE% %TIME% [INFO] Finished Size: %txtFinishedSize%

:get_finishedsizeinpoints
:: Get width and height from "Final Width and Height : 24 X 36 inches" comment by extracting 4th an 6th string in the comment.
for /f "tokens=4,6" %%A in ("%txtFinishedSize%") do (
    set /a numFinishedSizeWidth=%%A*72
    set /a numFinishedSizeHeight=%%B*72
)

set txtFinishedSizeOrientation="landscape"
if %numFinishedSizeHeight% GTR %numFinishedSizeWidth% set txtFinishedSizeOrientation="portrait"
>>%pathLog% echo %DATE% %TIME% [INFO] Finished Size Orientation: %txtFinishedSizeOrientation%

:: We also need the orientation of the PDF to see if we need to match it to the orientation of the final finished size
::
:: /EnfocusReport/PageBoxInfo/Page/MediaBox/@width
:: /EnfocusReport/PageBoxInfo/Page/MediaBox/@height

set numPDFHeight=0
set numPDFWidth=0

:get_pdfheight
for /f "delims=" %%H in ('%pathXML% sel -t -m "/EnfocusReport/PageBoxInfo/Page/MediaBox/@height" -v . -n "%VAULT%\%JOBNAME%_pitstop_preflight.xml"') do set numPDFHeight=%%H
>>%pathLog% echo %DATE% %TIME% [INFO] PDF height: %numPDFHeight%

:get_pdfwidth
for /f "delims=" %%W in ('%pathXML% sel -t -m "/EnfocusReport/PageBoxInfo/Page/MediaBox/@width" -v . -n "%VAULT%\%JOBNAME%_pitstop_preflight.xml"') do set numPDFWidth=%%W
>>%pathLog% echo %DATE% %TIME% [INFO] PDF width: %numPDFWidth%

set txtPDFOrientation="landscape" 
if %numPDFHeight% gtr %numPDFWidth% set txtPDFOrientation="portrait"
>>%pathLog% echo %DATE% %TIME% [INFO] PDF Orientation: %txtPDFOrientation%

set numPDFDegrees=0

if %txtFinishedSizeOrientation% == "portrait" (
    if %txtPDFOrientation% == "landscape" (
        set numPDFDegrees=90
    )
)
if %txtFinishedSizeOrientation% == "landscape" (
    %txtPDFOrientation% == "portrait" (
        set numPDFDegrees=-90
    )   
)

:save_master_variable_json
>>%pathJSON% echo {"txtText":"%txtOrderNumber% | %txtOrderName% | %txtFinishedSize% | Print %numQuantity%x","intWidth":"%numFinishedSizeWidth%","intHeight":"%numFinishedSizeHeight%","intDegrees":"%numPDFDegrees%"}

:next_module
copy /y "%INPUT%" "%OUTPUT%"
>>%pathLog% echo %DATE% %TIME% [INFO] Copied %INPUT% to %OUTPUT%

:success
exit /b 0